@@ -11,7 +11,7 @@
  *   Technical realization of Short Message Service (SMS)
  *   (3GPP TS 23.040 version 5.4.0 Release 5)
  *
- * $Id: packet-gsm_sms.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-gsm_sms.c 13056 2005-01-15 23:45:37Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -289,6 +289,10 @@ dis_field_addr(tvbuff_t *tvb, proto_tree *tree, guint32 *offset_p, gchar *title)
     case 0x00: str = "Unknown"; break;
     case 0x01: str = "International"; break;
     case 0x02: str = "National"; break;
+    case 0x03: str = "Network specific"; break;
+    case 0x04: str = "Subscriber"; break;
+    case 0x05: str = "Alphanumeric (coded according to 3GPP TS 23.038 GSM 7-bit default alphabet)"; break;
+    case 0x06: str = "Abbreviated number"; break;
     case 0x07: str = "Reserved for extension"; break;
     default: str = "Unknown, reserved (?)"; break;
     }
@@ -304,7 +308,14 @@ dis_field_addr(tvbuff_t *tvb, proto_tree *tree, guint32 *offset_p, gchar *title)
     switch (oct & 0x0f)
     {
     case 0x00: str = "Unknown"; break;
-    case 0x01: str = "ISDN/telephone"; break;
+    case 0x01: str = "ISDN/telephone (E.164/E.163)"; break;
+    case 0x03: str = "Data numbering plan (X.121)"; break;
+    case 0x04: str = "Telex numbering plan"; break;
+    case 0x05: str = "Service Centre Specific plan"; break;
+    case 0x06: str = "Service Centre Specific plan"; break;
+    case 0x08: str = "National numbering plan"; break;
+    case 0x09: str = "Private numbering plan"; break;
+    case 0x0a: str = "ERMES numbering plan (ETSI DE/PS 3 01-3)"; break;
     case 0x0f: str = "Reserved for extension"; break;
     default: str = "Unknown, reserved (?)"; break;
     }
@@ -730,6 +741,7 @@ static void
 dis_field_scts_aux(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 {
     guint8	oct, oct2, oct3;
+    char sign;
 
 
     oct = tvb_get_guint8(tvb, offset);
@@ -766,10 +778,13 @@ dis_field_scts_aux(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
+    sign = (oct & 0x08)?'-':'+';
+    oct = (oct >> 4) + (oct & 0x07) * 10;
+
     proto_tree_add_text(tree,
 	tvb, offset, 1,
-	"Timezone %d",
-	oct);
+	"Timezone: GMT %c %d hours %d minutes",
+	sign, oct / 4, oct % 4 * 15);
 }
 
 /* 9.2.3.11 */
@@ -905,6 +920,7 @@ dis_field_vp(tvbuff_t *tvb, proto_tree *tree, guint32 *offset_p, guint8 vp_form)
 		    "%s :  Validity Period Format: relative",
 		    bigbuf);
 
+		offset++;
 		/* go around again */
 		vp_form = 2;
 		break;
@@ -942,12 +958,12 @@ dis_field_vp(tvbuff_t *tvb, proto_tree *tree, guint32 *offset_p, guint8 vp_form)
 		proto_tree_add_text(subtree,
 		    tvb, offset, 3,
 		    "Hour %d%d, Minutes %d%d, Seconds %d%d",
-		    (oct & 0xf0) >> 4,
 		    oct & 0x0f,
-		    (oct2 & 0xf0) >> 4,
+		    (oct & 0xf0) >> 4,
 		    oct2 & 0x0f,
-		    (oct3 & 0xf0) >> 4,
-		    oct3 & 0x0f);
+		    (oct2 & 0xf0) >> 4,
+		    oct3 & 0x0f,
+		    (oct3 & 0xf0) >> 4);
 
 		done = TRUE;
 		break;
@@ -1952,12 +1968,12 @@ dis_msg_deliver(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
+    DIS_FIELD_RP(tree, 0x80, offset);
+
+    DIS_FIELD_UDHI(tree, 0x40, offset, udhi);
+
     DIS_FIELD_SRI(tree, 0x20, offset);
 
-    DIS_FIELD_UDHI(tree, 0x10, offset, udhi);
-
-    DIS_FIELD_RP(tree, 0x08, offset);
-
     DIS_FIELD_MMS(tree, 0x04, offset);
 
     DIS_FIELD_MTI(tree, 0x03, offset);
@@ -2017,7 +2033,7 @@ dis_msg_deliver_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
-    DIS_FIELD_UDHI(tree, 0x04, offset, udhi);
+    DIS_FIELD_UDHI(tree, 0x40, offset, udhi);
 
     DIS_FIELD_MTI(tree, 0x03, offset);
 
@@ -2046,9 +2062,9 @@ dis_msg_deliver_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
     if (oct & 0x80)
     {
 	dis_field_fcs(tvb, tree, offset, oct);
+	offset++;
     }
 
-    offset++;
     pi = tvb_get_guint8(tvb, offset);
 
     dis_field_pi(tvb, tree, offset, pi);
@@ -2136,11 +2152,11 @@ dis_msg_submit(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
-    DIS_FIELD_SRR(tree, 0x80, offset);
+    DIS_FIELD_RP(tree, 0x80, offset);
 
     DIS_FIELD_UDHI(tree, 0x40, offset, udhi);
 
-    DIS_FIELD_RP(tree, 0x20, offset);
+    DIS_FIELD_SRR(tree, 0x20, offset);
 
     DIS_FIELD_VPF(tree, 0x18, offset, &vp_form);
 
@@ -2208,7 +2224,7 @@ dis_msg_submit_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
-    DIS_FIELD_UDHI(tree, 0x04, offset, udhi);
+    DIS_FIELD_UDHI(tree, 0x40, offset, udhi);
 
     DIS_FIELD_MTI(tree, 0x03, offset);
 
@@ -2229,16 +2245,30 @@ dis_msg_submit_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
     if (oct & 0x80)
     {
 	dis_field_fcs(tvb, tree, offset, oct);
+	offset++;
     }
 
-    offset++;
     pi = tvb_get_guint8(tvb, offset);
 
     dis_field_pi(tvb, tree, offset, pi);
-
     offset++;
+
     dis_field_scts(tvb, tree, &offset);
 
+    if (pi & 0x01) {
+	if (length <= (offset - saved_offset)) {
+	    proto_tree_add_text(tree,
+		tvb, offset, -1,
+		"Short Data (?)");
+	    return;
+	}
+
+	oct = tvb_get_guint8(tvb, offset);
+
+	dis_field_pid(tvb, tree, offset, oct);
+	offset++;
+    }
+
     if (pi & 0x02)
     {
 	if (length <= (offset - saved_offset))
@@ -2249,10 +2279,10 @@ dis_msg_submit_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 	    return;
 	}
 
-	offset++;
 	oct = tvb_get_guint8(tvb, offset);
 
 	dis_field_dcs(tvb, tree, offset, oct, &seven_bit, &eight_bit, &ucs2, &compressed);
+	offset++;
     }
 
     if (pi & 0x04)
@@ -2265,17 +2295,15 @@ dis_msg_submit_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 	    return;
 	}
 
-	offset++;
 	oct = tvb_get_guint8(tvb, offset);
 	udl = oct;
 
 	DIS_FIELD_UDL(tree, offset);
+	offset++;
     }
 
     if (udl > 0)
     {
-	offset++;
-
 	dis_field_ud(tvb, tree, offset, length - (offset - saved_offset), udhi, udl,
 	    seven_bit, eight_bit, ucs2, compressed);
     }
@@ -2306,11 +2334,11 @@ dis_msg_status_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
-    DIS_FIELD_SRQ(tree, 0x10, offset);
+    DIS_FIELD_UDHI(tree, 0x40, offset, udhi);
 
-    DIS_FIELD_MMS(tree, 0x08, offset);
+    DIS_FIELD_SRQ(tree, 0x20, offset);
 
-    DIS_FIELD_UDHI(tree, 0x04, offset, udhi);
+    DIS_FIELD_MMS(tree, 0x04, offset);
 
     DIS_FIELD_MTI(tree, 0x03, offset);
 
@@ -2415,9 +2443,9 @@ dis_msg_command(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
 
     oct = tvb_get_guint8(tvb, offset);
 
-    DIS_FIELD_SRR(tree, 0x08, offset);
+    DIS_FIELD_UDHI(tree, 0x40, offset, udhi);
 
-    DIS_FIELD_UDHI(tree, 0x04, offset, udhi);
+    DIS_FIELD_SRR(tree, 0x20, offset);
 
     DIS_FIELD_MTI(tree, 0x03, offset);
 
@@ -2514,7 +2542,18 @@ dissect_gsm_sms(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/*
 	 * convert the 2 bit value to one based on direction
 	 */
-	msg_type |= ((pinfo->p2p_dir == P2P_DIR_RECV) ? 0x04 : 0x00);
+	if (pinfo->p2p_dir == P2P_DIR_UNKNOWN)
+	{
+	    /* Return Result ... */
+	    if (msg_type == 0) /* SMS-DELIVER */
+	    {
+		msg_type |= 0x04; /* see the msg_type_strings */
+	    }
+	}
+	else
+	{
+	    msg_type |= ((pinfo->p2p_dir == P2P_DIR_RECV) ? 0x04 : 0x00);
+	}
 
 	str = my_match_strval(msg_type, msg_type_strings, &idx);
 
