@@ -3,7 +3,7 @@
  * Routines for LWAPP encapsulated packet disassembly
  * draft-ohara-capwap-lwapp-N (the current draft is 0)
  *
- * $Id: packet-lwapp.c 12593 2004-11-24 09:13:52Z guy $
+ * $Id: packet-lwapp.c 13366 2005-02-09 23:38:00Z lroland $
  *
  * Copyright (c) 2003 by David Frascone <dave@frascone.com>
  *
@@ -37,7 +37,7 @@
 #include <time.h>
 #include <glib.h>
 #include <epan/filesystem.h>
-#include "xmlstub.h"
+#include <epan/xmlstub.h>
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
