@@ -3,7 +3,7 @@
  * Copyright 2001, Tom Uijldert <tom.uijldert@cmg.nl>
  * Copyright 2004, Olivier Biot
  *
- * $Id: packet-mmse.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-mmse.c 12959 2005-01-05 10:27:22Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -44,6 +44,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
+#include <epan/strutil.h>
 #include "packet-wap.h"
 #include "packet-wsp.h"
 /* #include "packet-mmse.h" */		/* We autoregister	*/
@@ -1168,11 +1169,12 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
 			count2 = get_encoded_strval(tvb,
 				offset + count + count1, &strval);
 			/* Now render the fields */
-			ti = proto_tree_add_string_format(tree,
+			ti = proto_tree_add_string_format(mmse_tree,
 				hf_mmse_prev_sent_by,
 				tvb, offset - 1, 1 + count + length,
-				"%s (Forwarded-count=%u)",
-				strval, fwd_count);
+				strval, "%s (Forwarded-count=%u)",
+				format_text(strval, strlen(strval)),
+				fwd_count);
 			subtree = proto_item_add_subtree(ti,
 				ett_mmse_hdr_details);
 			proto_tree_add_uint(subtree,
@@ -1204,11 +1206,12 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
 			tmptime.nsecs = 0;
 			strval = abs_time_to_str(&tmptime);
 			/* Now render the fields */
-			ti = proto_tree_add_string_format(tree,
+			ti = proto_tree_add_string_format(mmse_tree,
 				hf_mmse_prev_sent_date,
 				tvb, offset - 1, 1 + count + length,
-				"%s (Forwarded-count=%u)",
-				strval, fwd_count);
+				strval, "%s (Forwarded-count=%u)",
+				format_text(strval, strlen(strval)),
+				fwd_count);
 			subtree = proto_item_add_subtree(ti,
 				ett_mmse_hdr_details);
 			proto_tree_add_uint(subtree,
@@ -1217,7 +1220,6 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
 			proto_tree_add_string(subtree,
 				hf_mmse_prev_sent_date_date,
 				tvb, offset + count + count1, count2, strval);
-			g_free(strval);
 		    }
 		    offset += length + count;
 		    break;
@@ -1246,9 +1248,10 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
 			    if (tree) {
 				proto_tree_add_text(mmse_tree, tvb, offset - 1,
 					length + 1, "%s: %s (Not decoded)",
-					hdr_name, strval);
-				g_free(strval);
+					hdr_name,
+					format_text(strval, strlen(strval)));
 			    }
+			    g_free(strval);
 			} else { /* General form with length */
 			    if (peek == 0x1F) { /* Value length in guintvar */
 				guint length_len = 0;
@@ -1283,7 +1286,9 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
 				    length + length2,
 				    (const char *) tvb_get_ptr(
 					    tvb, offset, length + length2),
-				    "%s: %s", strval, strval2);
+				    "%s: %s",
+				    format_text(strval, strlen(strval)),
+				    format_text(strval2, strlen(strval2)));
 			}
 			g_free(strval2);
 			offset += length + length2;
@@ -1622,7 +1627,7 @@ proto_register_mmse(void)
 	},
 	{   &hf_mmse_prev_sent_date_date,
 	    {   "Date", "mmse.previously_sent_date.date",
-		FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x00,
+		FT_STRING, BASE_NONE, NULL, 0x00,
 		"Time when the MM has been previously sent.",
     		HFILL
 	    }
