@@ -3,7 +3,7 @@
  *
  * Huagang XIE <huagang@intruvert.com>
  *
- * $Id: packet-mysql.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-mysql.c 13366 2005-02-09 23:38:00Z lroland $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,7 +40,7 @@
 #include <epan/conversation.h>
 
 #include "packet-tcp.h"
-#include "reassemble.h"
+#include <epan/reassemble.h>
 #include <epan/prefs.h>
 
 /* Capabilities */
@@ -251,12 +251,12 @@ dissect_mysql_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	gboolean	is_response;
 
-	conversation = find_conversation(&pinfo->src, &pinfo->dst, pinfo->ptype,
+	conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
 		pinfo->srcport, pinfo->destport, 0);
 
 	if (!conversation) {
 		/* create a new conversation */
-		conversation = conversation_new(&pinfo->src, &pinfo->dst, pinfo->ptype,
+		conversation = conversation_new(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
 				pinfo->srcport, pinfo->destport, 0);
 	}
 
