@@ -1,11 +1,10 @@
 /*
- * $Id: ftype-none.c,v 1.5 2003/02/08 04:22:37 gram Exp $
+ * $Id: ftype-none.c 11796 2004-08-22 00:31:58Z guy $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 2001 Gerald Combs
  *
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -33,29 +32,35 @@ ftype_register_none(void)
 {
 
 	static ftype_t none_type = {
-		"FT_NONE",
-		"label",
-		0,
-		NULL,
-		NULL,
-		NULL,
+		"FT_NONE",			/* name */
+		"label",			/* pretty_name */
+		0,				/* wire_size */
+		NULL,				/* new_value */
+		NULL,				/* free_value */
+		NULL,				/* val_from_unparsed */
+		NULL,				/* val_from_string */
 		NULL,				/* val_to_string_repr */
 		NULL,				/* len_string_repr */
 
-		NULL,
-		NULL,
-		NULL,
+		NULL,				/* set_value */
+		NULL,				/* set_value_integer */
+		NULL,				/* set_value_integer64 */
+		NULL,				/* set_value_floating */
 
-		NULL,
-		NULL,
-		NULL,
+		NULL,				/* get_value */
+		NULL,				/* get_value_integer */
+		NULL,				/* get_value_integer64 */
+		NULL,				/* get_value_floating */
 
-		NULL,
-		NULL,
-		NULL,
-		NULL,
-		NULL,
-		NULL,
+		NULL,				/* cmp_eq */
+		NULL,				/* cmp_ne */
+		NULL,				/* cmp_gt */
+		NULL,				/* cmp_ge */
+		NULL,				/* cmp_lt */
+		NULL,				/* cmp_le */
+		NULL,				/* cmp_bitwise_and */
+		NULL,				/* cmp_contains */
+		NULL,				/* cmp_matches */
 
 		NULL,
 		NULL,
