@@ -1,7 +1,7 @@
 /* http_stat.c
  * http_stat   2003 Jean-Michel FAYARD
  *
- * $Id: http_stat.c 12910 2005-01-01 02:57:02Z guy $
+ * $Id: http_stat.c 13289 2005-02-04 18:44:44Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -502,7 +502,7 @@ gtk_httpstat_init(char *optarg)
     window_present(sp->win);
 
 	http_init_hash(sp);
-	retap_packets(&cfile);
+	cf_retap_packets(&cfile);
 }
 
 static tap_dfilter_dlg http_stat_dlg = {
