@@ -4,7 +4,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
 *
-* $Id: mate_util.c 13054 2005-01-15 23:34:29Z guy $
+* $Id: mate_util.c 13488 2005-02-24 04:11:31Z lego $
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.com>
@@ -54,6 +54,7 @@ void dbg_print(const guint* which, guint how, FILE* where, guint8* fmt, ... ) {
 		g_message(debug_buffer);
 	} else {
 		fputs(debug_buffer,where);
+		fputs("\n",where);
 	}
 
 }
@@ -66,7 +67,6 @@ void dbg_print(const guint* which, guint how, FILE* where, guint8* fmt, ... ) {
  * we'll keep only one copy of each as key to a hash with a count of
  * subscribers as value.
  ***************************************************************************/
-/* FIXME: use hash fom glib 1.X not 2.X */
 
 /**
  * scs_init:
@@ -136,7 +136,7 @@ guint8* scs_subscribe(SCS_collection* c, guint8* s) {
 	size_t len = 0;
 	GMemChunk* chunk = NULL;
 	
-	g_hash_table_lookup_extended(c->hash,s,(gpointer*)&orig,(gpointer*)&ip);
+	g_hash_table_lookup_extended(c->hash,(gconstpointer)s,(gpointer*)&orig,(gpointer*)&ip);
 
 	if (ip) {
 		(*ip)++;
@@ -187,7 +187,7 @@ void scs_unsubscribe(SCS_collection* c, guint8* s) {
 	size_t len = 0xffff;
 	GMemChunk* chunk = NULL;
 	
-	g_hash_table_lookup_extended(c->hash,s,(gpointer*)&orig,(gpointer*)&ip);
+	g_hash_table_lookup_extended(c->hash,(gconstpointer)s,(gpointer*)&orig,(gpointer*)&ip);
 
 	if (ip) {
 		if (*ip == 0) {
@@ -212,7 +212,7 @@ void scs_unsubscribe(SCS_collection* c, guint8* s) {
 			(*ip)--;
 		}
 	} else {
-		g_warning("unsusbcribe: already deleted: '%s'?",s);
+		g_warning("unsusbcribe: not subscribed");
 	}
 }
 
@@ -1217,6 +1217,9 @@ extern AVPL* new_avpl_exact_match(guint8* name,AVPL* src, AVPL* op, gboolean cop
 	dbg_print(dbg_avpl_op,3,dbg_fp,"new_avpl_every_match: %X src=%X op=%X name='%s'",newavpl,src,op,name);
 #endif
 
+	if (op->len == 0)
+		return newavpl;
+		
 	cs = src->null.next;
 	co = op->null.next;
 	while(1) {
@@ -1624,7 +1627,7 @@ LoAL* load_loal_error(FILE* fp, LoAL* loal, AVPL* curr, int linenum, guint8* fmt
 }
 
 
-/*  the maximum lenght allowed for a line */
+/*  the maximum length allowed for a line */
 #define MAX_ITEM_LEN	8192
 
 /* this two ugly things are used for tokenizing */
@@ -1694,7 +1697,7 @@ extern LoAL* loal_from_file(guint8* filename) {
 			}
 
 			if ( i >= MAX_ITEM_LEN - 1  ) {
-				return load_loal_error(fp,loal,curr,linenum,"Maximum item lenght exceeded");
+				return load_loal_error(fp,loal,curr,linenum,"Maximum item length exceeded");
 			}
 
 			switch(state) {
