@@ -1,6 +1,6 @@
 /* libpcap.c
  *
- * $Id: libpcap.c 12700 2004-12-09 19:12:28Z guy $
+ * $Id: libpcap.c 13212 2005-01-31 03:03:02Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -168,6 +168,8 @@ static const struct {
 	{ 10,		WTAP_ENCAP_FDDI },
 #endif
 
+	{ 32,		WTAP_ENCAP_REDBACK },
+
 	/*
 	 * 50 is DLT_PPP_SERIAL in NetBSD; it appears that DLT_PPP
 	 * on BSD (at least according to standard tcpdump) has, as
@@ -294,9 +296,11 @@ static const struct {
 	{ 129,		WTAP_ENCAP_ARCNET_LINUX },
 
 	/*
-	 * Values 130 through 137 are reserved for use in Juniper
-	 * hardware.
+	 * Values 130 through 137 not listed here are reserved for use
+	 * in Juniper hardware.
 	 */
+	{ 135,		WTAP_ENCAP_JUNIPER_ATM2 }, /* various encapsulations captured on the ATM2 PIC */
+	{ 137,		WTAP_ENCAP_JUNIPER_ATM1 }, /* various encapsulations captured on the ATM1 PIC */
 
 	{ 138,		WTAP_ENCAP_APPLE_IP_OVER_IEEE1394 },
 						/* Apple IP-over-IEEE 1394 */
